@@ -1,5 +1,5 @@
 package DBIx::Class::DeploymentHandler::Types;
-$DBIx::Class::DeploymentHandler::Types::VERSION = '0.002212';
+$DBIx::Class::DeploymentHandler::Types::VERSION = '0.002235';
 use strict;
 use warnings;
 
@@ -13,13 +13,12 @@ coerce 'DBIx::Class::DeploymentHandler::Databases'
  => from 'Str'
  => via { [$_] };
 
-subtype 'StrSchemaVersion'
- => as 'Str'
- => message {
-  defined $_
-    ? "Schema version (currently '$_') must be a string"
-    : 'Schema version must be defined'
- };
+subtype 'DBIx::Class::DeploymentHandler::VersionNonObj'
+ => as 'Str';
+
+coerce 'DBIx::Class::DeploymentHandler::VersionNonObj'
+ => from 'Object'
+ => via { $_->numify };
 
 no Moose::Util::TypeConstraints;
 1;
@@ -40,7 +39,7 @@ Arthur Axel "fREW" Schmidt <frioux+cpan@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Arthur Axel "fREW" Schmidt.
+This software is copyright (c) 2025 by Arthur Axel "fREW" Schmidt.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
